# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

### Changed

### Deprecated

### Removed

### Fixed

### Security

## [0.0.1] - 2025-04-24

Initial release 🎉

[unreleased]: https://github.com/jkeifer/griffine/compare/v0.1.0...HEAD
[0.0.1]: https://github.com/jkeifer/griffine/releases/tag/v0.1.0
